<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes" encoding="UTF-8"/>

    <xsl:param name="radar-config-file"/>
	<xsl:param name="report-to-merge"/>
    <xsl:param name="quality-report-path"/>
    <xsl:param name="sequence-id"/>
    <xsl:param name="days-since-last"/>
    <xsl:param name="log"/>

    <xsl:variable name="report-to-merge-doc" 	select="document($report-to-merge)"/>
    <xsl:variable name="radar-config" 			select="document($radar-config-file)"/>

    <xsl:template match="radar-report">
    	<xsl:choose>
    		<xsl:when test="$log = 'true'">
		    	<xsl:message>
		radar-config-file:<xsl:value-of select="$radar-config-file"/>
		report-to-merge:<xsl:value-of select="$report-to-merge"/>
		quality-report-path:<xsl:value-of select="$quality-report-path"/>
		sequence-id:<xsl:value-of select="$sequence-id"/>
		days-since-last:<xsl:value-of select="$days-since-last"/>    		
		XML files open:
		radar-config:<xsl:value-of select="$radar-config/radar-config/attribute::name"/>
		report-to-merge:<xsl:value-of select="name($report-to-merge-doc/*)"/>
		    	</xsl:message>
		    </xsl:when>
	    </xsl:choose>
    	 
    	<xsl:copy>
   			<xsl:attribute name="system"><xsl:value-of select="$report-to-merge-doc/radar-report/@system"/></xsl:attribute>
            <xsl:apply-templates select="node()"/>
            <xsl:if test="count(defined-metrics) = 0">
                <defined-metrics>
                    <system>
                        <xsl:variable name="quality-report-doc" select="document(concat($quality-report-path,'system_quality_report.xml'))"/>
                        <xsl:apply-templates select="$quality-report-doc/*" mode="defined-metric"/>
                    </system>
                    <subsystems>
                        <xsl:for-each select="$radar-config/radar-config/subsystems/subsystem">
		                    <xsl:variable name="subsystem-name" select="normalize-space(name)"/>
                            <xsl:variable name="quality-report-doc-subsystem" select="document(concat($quality-report-path,'subsystem_quality_report_',$subsystem-name,'.xml'))"/>
                            <subsystem name="{$subsystem-name}">
                                <xsl:apply-templates select="$quality-report-doc-subsystem/*" mode="defined-metric"/>
                            </subsystem>
                        </xsl:for-each>
                    </subsystems>
					<!--packages>
						<xsl:for-each select="packages/package">
		                    <xsl:variable name="package-name" select="@name"/>
                            <xsl:variable name="quality-report-doc-package" select="document(concat($quality-report-path,'package_quality_report_',$package-name,'.xml'))"/>
                            <subsystem name="{$subsystem-name}">
                                <xsl:apply-templates select="$quality-report-doc-package/*" mode="defined-metric"/>
                            </subsystem>
                        </xsl:for-each>
					</packages-->
                </defined-metrics>
            </xsl:if>
	   	</xsl:copy>
	</xsl:template>

    <xsl:template match="sources">
      	<xsl:variable name="sources-element" select="current()"/>
      	<xsl:copy>
      	 	<xsl:apply-templates select="@*|node()"/>
      	 	<xsl:for-each select="$report-to-merge-doc/radar-report/sources/source">
      	 		<xsl:variable name="source-data" select="normalize-space(.)"/>
	      	 	<xsl:if test="count($sources-element/source[normalize-space(.)=$source-data])=0">
	      	 		<xsl:copy>
	      	 			<xsl:copy-of select="."/>
	      	 		</xsl:copy>
	      	 	</xsl:if>
      	 	</xsl:for-each>
      	</xsl:copy>
   	</xsl:template>


   	<xsl:template match="reports">
      	<xsl:copy>
      	 	<xsl:apply-templates select="@*|node()"/>
      	 	<report>
      	 		<xsl:attribute name="seq-id"><xsl:value-of select="$sequence-id"/></xsl:attribute>
      	 		<xsl:element name="version"><xsl:value-of select="$report-to-merge-doc/radar-report/@version"/></xsl:element>
      	 		<xsl:element name="date"><xsl:value-of select="$report-to-merge-doc/radar-report/@date"/></xsl:element>
      	 		<xsl:element name="days-since-last"><xsl:value-of select="$days-since-last"/></xsl:element>
      	 	</report>
      	</xsl:copy>
   	</xsl:template>

    <xsl:template match="defined-metrics">
      	<xsl:copy>
      	 	<xsl:for-each select="system">
                <xsl:copy>
                    <xsl:variable name="quality-report-doc" select="document(concat($quality-report-path,'system_quality_report.xml'))"/>
                    <xsl:apply-templates select="node()" mode="defined-metric">
                       <xsl:with-param name="metric-root" select="$quality-report-doc"/>
                    </xsl:apply-templates>
                </xsl:copy>
      	 	</xsl:for-each>

            <xsl:for-each select="subsystems">
                <xsl:copy>
                    <xsl:for-each select="subsystem">
                        <xsl:copy>
                            <xsl:apply-templates select="@*"/>
                            <xsl:variable name="subsystem-name" select="@name"/>
                            <xsl:variable name="quality-report-doc" select="document(concat($quality-report-path,'subsystem_quality_report_',$subsystem-name,'.xml'))"/>
                            <xsl:apply-templates select="node()" mode="defined-metric">
                               <xsl:with-param name="metric-root" select="$quality-report-doc"/>
                            </xsl:apply-templates>
                        </xsl:copy>
                    </xsl:for-each>
                </xsl:copy>
      	 	</xsl:for-each>
      	</xsl:copy>
   	</xsl:template>


   	<!-- all packages-related templates -->
   	<xsl:template match="packages">
   		<xsl:variable name="packages-element" select="current()"/>
      	<xsl:copy>
      	 	<xsl:apply-templates select="@*|node()"/>
      	 	<xsl:for-each select="$report-to-merge-doc/radar-report/packages/package">
      	 		<xsl:variable name="package-name" select="@name"/>
	      	 	<xsl:if test="count($packages-element/package[normalize-space(@name)=$package-name])=0">
	      	 		<xsl:copy>
	      	 			<xsl:apply-templates select="@*"/>
	      	 			<xsl:apply-templates select="statistics" mode="new-package"/>
	      	 			<xsl:apply-templates select="classes" mode="new-package"/>
	      	 			<package-availability>
	      	 				<report>
	      	 					<xsl:attribute name="seq-id"><xsl:value-of select="$sequence-id"/></xsl:attribute>
	      	 					<xsl:if test="(../../statistics/source-metrics/ncss/value[@seq-id=$sequence-id]/@value != ../../statistics/source-metrics/ncss/value[@seq-id=($sequence-id - 1)]/@value)">
	      	 						<xsl:attribute name="changed-since-last"><xsl:value-of select="'true'"/></xsl:attribute>
	      	 					</xsl:if>
	      	 				</report>
	      	 			</package-availability>
	      	 		</xsl:copy>
	      	 	</xsl:if>
      	 	</xsl:for-each>
      	</xsl:copy>
   	</xsl:template>

   <xsl:template match="package-availability">
      	<xsl:variable name="package-name" select="../@name"/>
      	<xsl:copy>
      	 	<xsl:apply-templates select="@*|node()"/>
      	 	<xsl:if test="$report-to-merge-doc/radar-report/packages/package[@name=$package-name]">
	    		<report>
 					<xsl:attribute name="seq-id"><xsl:value-of select="$sequence-id"/></xsl:attribute>
 				</report>
 			</xsl:if>
      	</xsl:copy>
   	</xsl:template>


   <!-- Add new statistics data -->
   <xsl:template match="statistics" mode="new-package">
   		<xsl:variable name="package-name" select="../@name"/>
   		<xsl:copy> <!-- statistics -->
			<xsl:for-each select="child::*">
				<xsl:copy> <!-- statistic genre -->
					<xsl:for-each select="child::*">
						<xsl:copy> <!-- specific statistic -->
							<xsl:apply-templates select="@*"/>
							<xsl:call-template name="insert-value-element">
								<xsl:with-param name="value" select="."/>
							</xsl:call-template>
						</xsl:copy>
					</xsl:for-each>
				</xsl:copy>
			</xsl:for-each>
		</xsl:copy>
	</xsl:template>

	<!-- Go into all these existing statistics elements and add new data -->
   <xsl:template match="statistics">
   		<xsl:variable name="package-name" select="../@name"/>
   		<xsl:variable name="dynamics-master-statistics-element" select="current()"/>
   		<xsl:variable name="report-to-merge-statistics-element" select="$report-to-merge-doc/radar-report/packages/package[@name=$package-name]/statistics"/>

   		<xsl:copy>
   			<!-- statistic genre -->
   			<xsl:for-each select="child::*">
				<xsl:copy>
					<xsl:apply-templates select="@*"/>
					<xsl:variable name="node-name-level1" select="name()"/>
					<!-- specific statistic -->
					<xsl:for-each select="child::*">
						<xsl:variable name="node-name-level2" select="name()"/>
						<xsl:variable name="name-attr" select="@name"/>
						<xsl:copy>
							<xsl:apply-templates select="@*|node()"/>
							<xsl:for-each select="$report-to-merge-statistics-element/descendant::node()[name()=$node-name-level2]">
								<xsl:if test="((name()='subsystem') and (@name = $name-attr)) or (not(name()='subsystem'))">
									<xsl:call-template name="insert-value-element">
										<xsl:with-param name="value" select="."/>
									</xsl:call-template>
								</xsl:if>
							</xsl:for-each>
						</xsl:copy>
					</xsl:for-each>
					<xsl:for-each select="$report-to-merge-statistics-element/*[name()=$node-name-level1]/*">
						<xsl:variable name="node-name-level2" select="name()"/>
						<xsl:if test="count($dynamics-master-statistics-element/*[name()=$node-name-level1]/*[name()=$node-name-level2]) = 0">
							<xsl:copy>
								<xsl:apply-templates select="@*"/>
								<xsl:call-template name="insert-value-element">
									<xsl:with-param name="value" select="."/>
								</xsl:call-template>
							</xsl:copy>
						</xsl:if>
					</xsl:for-each>
				</xsl:copy>
			</xsl:for-each>
			<xsl:for-each select="$report-to-merge-statistics-element/*">
				<xsl:variable name="node-name-level1" select="name()"/>
				<xsl:if test="count($dynamics-master-statistics-element/*[name()=$node-name-level1]) = 0">
					<xsl:copy>
						<xsl:apply-templates select="@*"/>
						<xsl:for-each select="*">
							<xsl:copy>
								<xsl:apply-templates select="@*"/>
								<xsl:call-template name="insert-value-element">
									<xsl:with-param name="value" select="."/>
								</xsl:call-template>
							</xsl:copy>
						</xsl:for-each>
					</xsl:copy>
				</xsl:if>
			</xsl:for-each>
		</xsl:copy>
	</xsl:template>

	<!-- Add new classes data -->
	<xsl:template match="classes" mode="new-package">
		<xsl:copy>
			<!-- class -->
			<xsl:for-each select="class">
				<xsl:copy>
					<xsl:apply-templates select="@*"/>
					<!-- methods -->
					<xsl:apply-templates select="methods" mode="new-class"/>
					<xsl:call-template name="class-availability"/>
				</xsl:copy>
			</xsl:for-each>
		</xsl:copy>
	</xsl:template>

    <!-- Go into all these existing classes elements and add new data -->
   <xsl:template match="classes">
   		<xsl:variable name="package-name" select="../@name"/>
   		<xsl:variable name="report-to-merge-package-element" select="$report-to-merge-doc/radar-report/packages/package[@name=$package-name]"/>
   		<xsl:variable name="dynamics-master-classes-element" select="current()"/>
   		<xsl:variable name="report-to-merge-classes-element" select="$report-to-merge-package-element/classes"/>

   		<xsl:copy>
   			<!-- do a performance optimizing check -->
	   		<xsl:choose>
	   			<xsl:when test="(
	   								(../statistics/source-metrics/ncss/value[@seq-id = number($sequence-id - 1)]/@value = $report-to-merge-package-element/statistics/source-metrics/ncss)
		   								and
	   								(../statistics/test-metrics/line-coverage/value[@seq-id = number($sequence-id - 1)]/@value = $report-to-merge-package-element/statistics/test-metrics/line-coverage)
	   							)">
	   				<xsl:apply-templates select="class" mode="no-change-in-package"/>
	   			</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="class" mode="change-in-package">
						<xsl:with-param name="dynamics-master-classes-element" select="$dynamics-master-classes-element"/>
	   					<xsl:with-param name="report-to-merge-classes-element" select="$report-to-merge-classes-element"/>
					</xsl:apply-templates>
					<!-- add new classes -->
					<xsl:for-each select="$report-to-merge-classes-element/class">
						<xsl:variable name="new-class-name" select="@name"/>
						<xsl:if test="count($dynamics-master-classes-element/class[@name = $new-class-name]) = 0">
							<xsl:copy>
								<xsl:apply-templates select="@*"/>
								<!-- methods -->
								<xsl:apply-templates select="methods" mode="new-class"/>
								<xsl:call-template name="class-availability"/>
							</xsl:copy>
						</xsl:if>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:copy>
	</xsl:template>

	<!-- copy whole class hierarchy if no change in package -->
	<xsl:template match="class" mode="no-change-in-package">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<!-- methods -->
			<xsl:for-each select="methods">
				<xsl:copy>
					<xsl:apply-templates select="@*"/>
					<!-- method -->
					<xsl:apply-templates select="method" mode="no-change-in-class"/>
				</xsl:copy>
			</xsl:for-each>
			<xsl:apply-templates select="class-availability">
				<xsl:with-param name="changed-since-last" select="'false'"/>
			</xsl:apply-templates>
		</xsl:copy>
   	</xsl:template>

   	<!-- merge with new version document if change in package -->
	<xsl:template match="class" mode="change-in-package">
		<xsl:param name="dynamics-master-classes-element"/>
		<xsl:param name="report-to-merge-classes-element"/>

		<xsl:variable name="class-name" select="@name"/>
		<xsl:variable name="dynamics-master-this-class-element" select="current()"/>
		<xsl:variable name="report-to-merge-this-class-element" select="$report-to-merge-classes-element/class[@name = $class-name]"/>

		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<!-- methods -->
			<xsl:apply-templates select="methods">
				<xsl:with-param name="class-name" select="$class-name"/>
				<xsl:with-param name="dynamics-master-this-class-element" select="$dynamics-master-this-class-element"/>
				<xsl:with-param name="report-to-merge-this-class-element" select="$report-to-merge-this-class-element"/>
			</xsl:apply-templates>

			<xsl:apply-templates select="class-availability">
				<xsl:with-param name="changed-since-last">
					<xsl:choose>
						<xsl:when test="(
			   								(sum(descendant::ncss/value[@seq-id = number($sequence-id - 1)]/@value) = sum($report-to-merge-this-class-element/descendant::ncss))
		   								)">true</xsl:when>
						<xsl:otherwise>false</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
			</xsl:apply-templates>

		</xsl:copy>

	</xsl:template>

	<xsl:template name="class-availability">
	   	<class-availability>
	  	 	<report>
				<xsl:attribute name="seq-id"><xsl:value-of select="$sequence-id"/></xsl:attribute>
				<xsl:attribute name="changed-since-last"><xsl:choose><xsl:when test="$sequence-id != '1'">true</xsl:when><xsl:otherwise>false</xsl:otherwise></xsl:choose></xsl:attribute>
			</report>
		</class-availability>
   	</xsl:template>

	<xsl:template match="class-availability">
		<xsl:param name="changed-since-last"/>
      	<xsl:copy>
      	 	<xsl:apply-templates select="@*|node()"/>
    		<report>
				<xsl:attribute name="seq-id"><xsl:value-of select="$sequence-id"/></xsl:attribute>
				<xsl:attribute name="changed-since-last"><xsl:value-of select="normalize-space($changed-since-last)"/></xsl:attribute>
			</report>
      	</xsl:copy>
   	</xsl:template>

	<xsl:template match="methods">
		<xsl:param name="class-name" select="@name"/>
		<xsl:param name="dynamics-master-this-class-element"/>
		<xsl:param name="report-to-merge-this-class-element"/>
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates select="method" mode="change-in-class">
				<xsl:with-param name="report-to-merge-this-class-element" select="$report-to-merge-this-class-element"/>
			</xsl:apply-templates>

			<!-- add new methods -->
			<xsl:for-each select="$report-to-merge-this-class-element/methods/method">
				<xsl:variable name="new-method-name" select="@name"/>
				<xsl:if test="count($dynamics-master-this-class-element/methods/method[@name = $new-method-name]) = 0">
					<xsl:copy>
						<xsl:apply-templates select="@*"/>
						<!-- methods -->
						<xsl:apply-templates select="statistics" mode="new-method"/>
					</xsl:copy>
				</xsl:if>
			</xsl:for-each>
		</xsl:copy>
	</xsl:template>

	<!-- Add new methods data -->
	<xsl:template match="methods" mode="new-class">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<!-- method -->
			<xsl:for-each select="method">
				<xsl:copy>
					<xsl:apply-templates select="@*"/>
					<!-- statistics -->
					<xsl:for-each select="method">
						<xsl:copy>
							<xsl:apply-templates select="@*"/>
							<!-- statistics -->
							<xsl:apply-templates select="statistics" mode="new-method"/>
						</xsl:copy>
					</xsl:for-each>
					<xsl:apply-templates select="statistics" mode="new-method"/>
				</xsl:copy>
			</xsl:for-each>
		</xsl:copy>
   	</xsl:template>

   	<!-- copy whole class hierarchy if no change in class-->
	<xsl:template match="method" mode="no-change-in-class">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<!-- statistics -->
			<xsl:for-each select="statistics">
				<xsl:copy>
					<xsl:apply-templates select="@*"/>
					<!-- statistic -->
					<xsl:for-each select="*">
						<xsl:copy>
							<xsl:apply-templates select="@*|node()"/>
							<xsl:apply-templates select="value[position() = last()]" mode="copy-previous-value"/>
						</xsl:copy>
					</xsl:for-each>
				</xsl:copy>
			</xsl:for-each>
		</xsl:copy>
   	</xsl:template>

   	<!-- Add new methods data -->
	<xsl:template match="method" mode="change-in-class">
		<xsl:param name="report-to-merge-this-class-element"/>

		<xsl:variable name="method-name" select="@name"/>
		<xsl:variable name="dynamics-master-this-method-element" select="current()"/>
		<xsl:variable name="report-to-merge-this-method-element" select="$report-to-merge-this-class-element/methods/method[@name = $method-name]"/>
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<!-- statistics -->
			<xsl:for-each select="statistics">
				<xsl:copy>
					<!-- specific statistic -->
					<xsl:for-each select="child::*">
						<xsl:variable name="statistic-name" select="name()"/>
						<xsl:copy>
							<xsl:apply-templates select="@*|node()"/>
							<xsl:call-template name="insert-value-element">
								<xsl:with-param name="value" select="$report-to-merge-this-method-element/statistics/*[name() = $statistic-name]/."/>
								<xsl:with-param name="changed-since-last">
									<xsl:choose>
										<xsl:when test="(
															(count($dynamics-master-this-method-element/statistics/*[name() = $statistic-name]/value[@seq-id &lt; ($sequence-id)]) = 0)
																and
															(number($sequence-id) &gt; 1)
														)
															or
														(
															$report-to-merge-this-method-element/statistics/*[name() = $statistic-name]/.
															!= $dynamics-master-this-method-element/statistics/*[name() = $statistic-name]/value[@seq-id = ($sequence-id - 1)]/@value
														)">true</xsl:when>
										<xsl:otherwise>false</xsl:otherwise>
									</xsl:choose>
								</xsl:with-param>
							</xsl:call-template>
						</xsl:copy>
					</xsl:for-each>

					<!-- add new statistics, first due a performance optimizing check -->
					<xsl:if test="count($report-to-merge-this-method-element/statistics/*) != count($dynamics-master-this-method-element/statistics/*)">
						<xsl:for-each select="$report-to-merge-this-method-element/statistics/*">
							<xsl:variable name="new-statistic-name" select="name()"/>
							<xsl:if test="count($dynamics-master-this-method-element/statistics/*[name() = $new-statistic-name]) = 0">
								<xsl:copy>
									<xsl:apply-templates select="@*"/>
									<xsl:call-template name="insert-value-element">
										<xsl:with-param name="value" select="."/>
										<xsl:with-param name="changed-since-last" select="'false'"/>
									</xsl:call-template>
								</xsl:copy>
							</xsl:if>
						</xsl:for-each>
					</xsl:if>
				</xsl:copy>
			</xsl:for-each>
		</xsl:copy>
   	</xsl:template>

   	<!-- Add new statistcs data -->
   	<xsl:template match="statistics" mode="new-method">
		<xsl:copy>
			<!-- specific statistic -->
			<xsl:for-each select="child::*">
				<xsl:copy>
					<xsl:apply-templates select="@*"/>
					<xsl:call-template name="insert-value-element">
						<xsl:with-param name="value" select="."/>
						<xsl:with-param name="changed-since-last">
							<xsl:choose>
								<xsl:when test="(number($sequence-id) &gt; 1)">true</xsl:when>
								<xsl:otherwise>false</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:copy>
			</xsl:for-each>
		</xsl:copy>
   	</xsl:template>

   	<xsl:template match="value" mode="copy-previous-value">
		<xsl:copy>
	      	<xsl:attribute name="seq-id"><xsl:value-of select="$sequence-id"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
			<xsl:attribute name="changed-since-last">false</xsl:attribute>
	   	</xsl:copy>
	</xsl:template>

    <xsl:template match="metric" mode="defined-metric">
        <xsl:param name="metric-root"/>

        <xsl:variable name="abbreviation" select="@abbreviation"/>
        <xsl:copy>
	      	<xsl:apply-templates select="@*"/>
            <xsl:choose>
                <xsl:when test="not($metric-root)">
                    <xsl:call-template name="insert-value-element">
                        <xsl:with-param name="value" select="value/node()"/>
                        <xsl:with-param name="changed-since-last">false</xsl:with-param>
                    </xsl:call-template>
                    <xsl:apply-templates select="metric" mode="defined-metric"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="this-metric-root" select="$metric-root/descendant::metric[@abbreviation = $abbreviation]"/>
                    <xsl:apply-templates select="value"/>
                    <xsl:call-template name="insert-value-element">
                        <xsl:with-param name="value" select="$this-metric-root/value/node()"/>
                        <xsl:with-param name="changed-since-last">true</xsl:with-param>
                    </xsl:call-template>
                    <xsl:apply-templates select="metric" mode="defined-metric">
                        <xsl:with-param name="metric-root" select="$metric-root"/>
                    </xsl:apply-templates>
                </xsl:otherwise>
            </xsl:choose>
	   	</xsl:copy>
	</xsl:template>


   <xsl:template name="insert-value-element">
		<xsl:param name="value"/>
		<xsl:param name="changed-since-last"/>
		<value>
			<xsl:attribute name="seq-id"><xsl:value-of select="$sequence-id"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$value"/></xsl:attribute>
			<xsl:if test="string-length($changed-since-last) &gt; 0">
				<xsl:attribute name="changed-since-last"><xsl:value-of select="$changed-since-last"/></xsl:attribute>
			</xsl:if>
		</value>
   </xsl:template>

   <!-- Copy all nodes from here. Can be overridden by a more specific XPath -->
	<xsl:template match="@*|node()">
		<xsl:copy>
	      	<xsl:apply-templates select="@*|node()"/>
	   	</xsl:copy>
	</xsl:template>
</xsl:stylesheet>
