<?xml version="1.0"  encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	version="1.0"
	xmlns:lxslt="http://xml.apache.org/xslt"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
	extension-element-prefixes="redirect">

  	<xsl:import href="xradar://stylesheets/radar/graph/line-graph.xsl"/>
	<xsl:import href="xradar://stylesheets/radar/graph/simple-histogram-graph.xsl"/>
	<xsl:include href="xradar://stylesheets/radar/style/style.xsl"/>
	<xsl:include href="xradar://stylesheets/radar/dynamics/report/dynamics-report-standard-analysis-overview.xsl"/>
	<xsl:include href="xradar://stylesheets/radar/dynamics/report/dynamics-report-standard-analysis-classes.xsl"/>
    <xsl:include href="xradar://stylesheets/radar/dynamics/report/dynamics-report-standard-analysis-methods.xsl"/>
    <xsl:include href="xradar://stylesheets/radar/dynamics/report/dynamics-report-common.xsl"/>

  	<xsl:output method="html" encoding="UTF-8"/>

	<xsl:param name="docs-home"/>
    <xsl:param name="statics-configured"/>
    <xsl:param name="statics-root"/>
    <xsl:param name="radar-config-file"/>
    <xsl:param name="log"/>


<!--

 Stylesheet to be used with Radar Dynamic Analysis XML output.

 It creates a set of HTML files a la javadoc where you can browse easily
 through all subsystems and packages.

  -->

<xsl:param name="output.dir" select="'.'"/>

<xsl:template match="radar-report">

	<xsl:choose>
	<xsl:when test="$log = 'true'"> 
			<xsl:message>
				docs-home:<xsl:value-of select="$docs-home"/>
				statics-configured:<xsl:value-of select="$statics-configured"/>
				statics-root:<xsl:value-of select="$statics-root"/>
				radar-config-file:<xsl:value-of select="$radar-config-file"/>
				output.dir:<xsl:value-of select="$output.dir"/>
			</xsl:message>
		</xsl:when> 
	</xsl:choose>

   	<!-- create the index.html -->
     <xsl:call-template name="log-step">
     	<xsl:with-param name="log" select="$log"/>
     	<xsl:with-param name="step" select="'Generating index.html'"/>
     </xsl:call-template>
   	<redirect:write file="{$docs-home}/{$output.dir}/index.html">
    	<xsl:call-template name="index.html"/>
   	</redirect:write>
	<!-- create the stylesheet.css -->
    <xsl:call-template name="log-step">
     	<xsl:with-param name="log" select="$log"/>
     	<xsl:with-param name="step" select="'Generating style.css'"/>
     </xsl:call-template>
	<redirect:write file="{$docs-home}/{$output.dir}/stylesheet.css">
	  <xsl:call-template name="stylesheet.css">
	    <xsl:with-param name="log"          select="$log"/>
	    <xsl:with-param name="radar-config" select="document($radar-config-file)"/>
	  </xsl:call-template>
   	</redirect:write>

    <!-- create the all-subsystems.html at the root -->
    <xsl:call-template name="log-step">
     	<xsl:with-param name="log" select="$log"/>
     	<xsl:with-param name="step" select="'Generating all-subsystems.html'"/>
     </xsl:call-template>    
    <redirect:write file="{$docs-home}/{$output.dir}/all-subsystems.html">
    	<xsl:apply-templates select="subsystems" mode="all-subsystems"/>
    </redirect:write>
   	<!-- create the all-packages.html at the root -->
    <xsl:call-template name="log-step">
     	<xsl:with-param name="log" select="$log"/>
     	<xsl:with-param name="step" select="'Generating all-package.html'"/>
    </xsl:call-template>       	
   	<redirect:write file="{$docs-home}/{$output.dir}/all-packages.html">
    	<xsl:apply-templates select="packages" mode="all-packages"/>
  	</redirect:write>
	<!-- create the all-packages-subsystem-x.html at the root -->
	<xsl:call-template name="log-step">
     	<xsl:with-param name="log" select="$log"/>
     	<xsl:with-param name="step" select="'Generating all-package-*.html'"/>
    </xsl:call-template>    	
   	<xsl:for-each select="subsystems/subsystem">
	   	<redirect:write file="{$docs-home}/{$output.dir}/all-packages-subsystem-{@name}.html">
	  		<xsl:apply-templates select="current()" mode="all-packages-subsystem"/>
	  	</redirect:write>
	</xsl:for-each>

	<xsl:call-template name="log-step">
     	<xsl:with-param name="log" select="$log"/>
     	<xsl:with-param name="step" select="'Generating subsystems/overview-system.html'"/>
    </xsl:call-template>    
    <redirect:write file="{$docs-home}/{$output.dir}/subsystems/overview-system.html">
    	<xsl:call-template name="standard-analysis-overview">
		   <xsl:with-param name="defined-metrics-element" 				 select="defined-metrics/system"/>
		   <xsl:with-param name="defined-metrics-elements-subcomponents" select="defined-metrics/subsystems"/>
		   <xsl:with-param name="reports-element" 						 select="reports"/>
		   <xsl:with-param name="packages-element" 						 select="packages"/>
           <xsl:with-param name="subsystem-name" 						 select="''"/>
           <xsl:with-param name="page-type" 							 select="'overview'"/>
		</xsl:call-template>
    </redirect:write>
    <redirect:write file="{$docs-home}/{$output.dir}/subsystems/architecture-system.html">
    	<xsl:call-template name="standard-analysis-overview">
		   <xsl:with-param name="reports-element" select="reports"/>
		   <xsl:with-param name="packages-element" select="packages"/>
		   <xsl:with-param name="subsystem-name" select="''"/>
           <xsl:with-param name="page-type" select="'architecture'"/>
		</xsl:call-template>
    </redirect:write>
	<redirect:write file="{$docs-home}/{$output.dir}/subsystems/package-design-system.html">
    	<xsl:call-template name="standard-analysis-overview">
		   <xsl:with-param name="reports-element" select="reports"/>
		   <xsl:with-param name="packages-element" select="packages"/>
		   <xsl:with-param name="subsystem-name" select="''"/>
           <xsl:with-param name="page-type" select="'package-design'"/>
		</xsl:call-template>
    </redirect:write>
    <redirect:write file="{$docs-home}/{$output.dir}/subsystems/code-system.html">
    	<xsl:call-template name="standard-analysis-overview">
		   <xsl:with-param name="reports-element" select="reports"/>
		   <xsl:with-param name="packages-element" select="packages"/>
		   <xsl:with-param name="subsystem-name" select="''"/>
           <xsl:with-param name="page-type" select="'code'"/>
		</xsl:call-template>
    </redirect:write>
    <redirect:write file="{$docs-home}/{$output.dir}/subsystems/test-system.html">
    	<xsl:call-template name="standard-analysis-overview">
		   <xsl:with-param name="reports-element" select="reports"/>
		   <xsl:with-param name="packages-element" select="packages"/>
		   <xsl:with-param name="subsystem-name" select="''"/>
           <xsl:with-param name="page-type" select="'test'"/>
		</xsl:call-template>
    </redirect:write>
    <redirect:write file="{$docs-home}/{$output.dir}/subsystems/source-control-system.html">
    	<xsl:call-template name="standard-analysis-overview">
		   <xsl:with-param name="reports-element" select="reports"/>
		   <xsl:with-param name="packages-element" select="packages"/>
		   <xsl:with-param name="subsystem-name" select="''"/>
           <xsl:with-param name="page-type" select="'source control'"/>
		</xsl:call-template>
    </redirect:write>
    <redirect:write file="{$docs-home}/{$output.dir}/subsystems/system-specific-system.html">
    	<xsl:call-template name="standard-analysis-overview">
		   <xsl:with-param name="reports-element" select="reports"/>
		   <xsl:with-param name="packages-element" select="packages"/>
		   <xsl:with-param name="subsystem-name" select="''"/>
           <xsl:with-param name="page-type" select="'system specific'"/>
		</xsl:call-template>
    </redirect:write>


    <redirect:write file="{$docs-home}/{$output.dir}/subsystems/classes-analysis-system.html">
        <xsl:call-template name="standard-analysis-classes">
           <xsl:with-param name="reports-element" select="reports"/>
		   <xsl:with-param name="packages-element" select="packages"/>
		   <xsl:with-param name="subsystem-name" select="''"/>
        </xsl:call-template>
    </redirect:write>
    <redirect:write file="{$docs-home}/{$output.dir}/subsystems/methods-analysis-system.html">
        <xsl:call-template name="standard-analysis-methods">
           <xsl:with-param name="reports-element" select="reports"/>
		   <xsl:with-param name="packages-element" select="packages"/>
		   <xsl:with-param name="subsystem-name" select="''"/>
        </xsl:call-template>
    </redirect:write>
    <if test="/radar-report/packages/package[starts-with(@subsystem,$subsystem-name)]/statistics/test-metrics)">
    <redirect:write file="{$docs-home}/{$output.dir}/subsystems/methods-changed-since-last-version-analysis-system.html">
        <xsl:call-template name="standard-analysis-changed-since-last-methods">
           <xsl:with-param name="reports-element" select="reports"/>
		   <xsl:with-param name="packages-element" select="packages"/>
		   <xsl:with-param name="subsystem-name" select="''"/>
        </xsl:call-template>
    </redirect:write>
    </if>



    <!-- create the topview-subsystem-{@name}.html in subsystems catalog-->
    <xsl:for-each select="subsystems/subsystem">
        <xsl:variable name="subsystem-name" select="@name"/>
	   	<redirect:write file="{$docs-home}/{$output.dir}/subsystems/overview-subsystem-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="defined-metrics-element" select="/radar-report/defined-metrics/subsystems/subsystem[@name = $subsystem-name]"/>
               <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="subsystem-name" select="@name"/>
               <xsl:with-param name="page-type" select="'overview'"/>
			</xsl:call-template>
	  	</redirect:write>
        <redirect:write file="{$docs-home}/{$output.dir}/subsystems/architecture-subsystem-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="subsystem-name" select="@name"/>
               <xsl:with-param name="page-type" select="'architecture'"/>
			</xsl:call-template>
	  	</redirect:write>
        <redirect:write file="{$docs-home}/{$output.dir}/subsystems/package-design-subsystem-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="subsystem-name" select="@name"/>
               <xsl:with-param name="page-type" select="'package-design'"/>
			</xsl:call-template>
	  	</redirect:write>
        <redirect:write file="{$docs-home}/{$output.dir}/subsystems/code-subsystem-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="subsystem-name" select="@name"/>
               <xsl:with-param name="page-type" select="'code and duplication'"/>
			</xsl:call-template>
	  	</redirect:write>
        <redirect:write file="{$docs-home}/{$output.dir}/subsystems/test-subsystem-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="subsystem-name" select="@name"/>
               <xsl:with-param name="page-type" select="'test'"/>
			</xsl:call-template>
	  	</redirect:write>
        <redirect:write file="{$docs-home}/{$output.dir}/subsystems/source-control-subsystem-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="subsystem-name" select="@name"/>
               <xsl:with-param name="page-type" select="'source control'"/>
			</xsl:call-template>
	  	</redirect:write>

        <redirect:write file="{$docs-home}/{$output.dir}/subsystems/system-specific-subsystem-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="subsystem-name" select="@name"/>
               <xsl:with-param name="page-type" select="'system specific'"/>
			</xsl:call-template>
	  	</redirect:write>


        <redirect:write file="{$docs-home}/{$output.dir}/subsystems/classes-analysis-subsystem-{@name}.html">
            <xsl:call-template name="standard-analysis-classes">
               <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="subsystem-name" select="@name"/>
            </xsl:call-template>
        </redirect:write>
        <redirect:write file="{$docs-home}/{$output.dir}/subsystems/methods-analysis-subsystem-{@name}.html">
            <xsl:call-template name="standard-analysis-methods">
               <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="subsystem-name" select="@name"/>
            </xsl:call-template>
        </redirect:write>
        <if test="/radar-report/packages/package[starts-with(@subsystem,$subsystem-name)]/statistics/test-metrics)">
            <redirect:write file="{$docs-home}/{$output.dir}/subsystems/methods-changed-since-last-version-analysis-subsystem-{@name}.html">
                <xsl:call-template name="standard-analysis-changed-since-last-methods">
                   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
                   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
                   <xsl:with-param name="subsystem-name" select="@name"/>
                </xsl:call-template>
            </redirect:write>
        </if>
	</xsl:for-each>

	<!-- create the topview-package-{@name}.html in subsystems catalog-->
    <xsl:for-each select="packages/package">
    	<xsl:variable name="package-name" select="@name"/>
	   	<redirect:write file="{$docs-home}/{$output.dir}/packages/overview-package-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
               <xsl:with-param name="package-element" select="current()"/>
               <xsl:with-param name="single-package" select="'true'"/>
               <xsl:with-param name="page-type" select="'overview'"/>
            </xsl:call-template>
	  	</redirect:write>

        <redirect:write file="{$docs-home}/{$output.dir}/packages/architecture-package-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="single-package" select="'true'"/>
			   <xsl:with-param name="package-element" select="current()"/>
               <xsl:with-param name="page-type" select="'architecture'"/>
			</xsl:call-template>
	  	</redirect:write>

        <redirect:write file="{$docs-home}/{$output.dir}/packages/package-design-package-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="single-package" select="'true'"/>
			   <xsl:with-param name="package-element" select="current()"/>
               <xsl:with-param name="page-type" select="'package-design'"/>
			</xsl:call-template>
	  	</redirect:write>

        <redirect:write file="{$docs-home}/{$output.dir}/packages/code-package-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="single-package" select="'true'"/>
			   <xsl:with-param name="package-element" select="current()"/>
               <xsl:with-param name="page-type" select="'code and duplication'"/>
			</xsl:call-template>
	  	</redirect:write>

        <redirect:write file="{$docs-home}/{$output.dir}/packages/test-package-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="single-package" select="'true'"/>
			   <xsl:with-param name="package-element" select="current()"/>
               <xsl:with-param name="page-type" select="'test'"/>
			</xsl:call-template>
	  	</redirect:write>

        <redirect:write file="{$docs-home}/{$output.dir}/packages/source-control-package-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="single-package" select="'true'"/>
			   <xsl:with-param name="package-element" select="current()"/>
               <xsl:with-param name="page-type" select="'source control'"/>
			</xsl:call-template>
	  	</redirect:write>

        <redirect:write file="{$docs-home}/{$output.dir}/packages/system-specific-package-{@name}.html">
	  		<xsl:call-template name="standard-analysis-overview">
			   <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="single-package" select="'true'"/>
			   <xsl:with-param name="package-element" select="current()"/>
               <xsl:with-param name="page-type" select="'system specific'"/>
			</xsl:call-template>
	  	</redirect:write>


        <redirect:write file="{$docs-home}/{$output.dir}/packages/classes-analysis-package-{@name}.html">
            <xsl:call-template name="standard-analysis-classes">
               <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="single-package" select="'true'"/>
			   <xsl:with-param name="package-element" select="current()"/>
            </xsl:call-template>
        </redirect:write>
        <redirect:write file="{$docs-home}/{$output.dir}/packages/methods-analysis-package-{@name}.html">
            <xsl:call-template name="standard-analysis-methods">
               <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="single-package" select="'true'"/>
			   <xsl:with-param name="package-element" select="current()"/>
            </xsl:call-template>
        </redirect:write>
        <if test="/radar-report/packages/package[starts-with(@subsystem,$subsystem-name)]/statistics/test-metrics)">
        <redirect:write file="{$docs-home}/{$output.dir}/packages/methods-changed-since-last-version-analysis-package-{@name}.html">
            <xsl:call-template name="standard-analysis-changed-since-last-methods">
               <xsl:with-param name="reports-element" select="/radar-report/reports"/>
			   <xsl:with-param name="packages-element" select="/radar-report/packages"/>
			   <xsl:with-param name="single-package" select="'true'"/>
			   <xsl:with-param name="package-element" select="current()"/>
            </xsl:call-template>
        </redirect:write>
        </if>
	</xsl:for-each>

</xsl:template>


<xsl:template name="index.html">
<html>
   <head>
      <title>XRadar Dynamics Analysis</title>
   </head>
      <frameset cols="20%,80%">
         <frameset rows="40%,60%">
            <frame src="{$output.dir}/all-subsystems.html" name="subsystemListFrame"/>
            <frame src="{$output.dir}/all-packages.html" name="packageListFrame"/>
         </frameset>
         <frame src="{$output.dir}/subsystems/overview-system.html" name="analysisFrame"/>
      </frameset>
      <noframes>
         <h2>Frame Alert</h2>
         <p>
            This document is designed to be viewed using the frames feature. If you see this message, you are using a non-frame-capable web client.
         </p>
      </noframes>
</html>
</xsl:template>


<xsl:template match="packages" mode="all-packages">
  <html>
    <head>
      <link rel="stylesheet" type="text/css" href="stylesheet.css"/>
    </head>
    <body>
  <table width="100%"><tr align="left"><td></td><td align="right">
   </td></tr></table>
      <h2>All Packages</h2>
        <table width="100%">
          <xsl:apply-templates select="package" mode="all-packages-link">
            <xsl:sort select="@name"/>
          </xsl:apply-templates>
        </table>
    </body>
  </html>
</xsl:template>

<xsl:template match="subsystem" mode="all-packages-subsystem">
  <xsl:variable name="subsystem-name" select="@name"/>
  <html>
    <head>
      <link rel="stylesheet" type="text/css" href="stylesheet.css"/>
    </head>
    <body>
  <table width="100%"><tr align="left"><td></td><td align="right">
   </td></tr></table>
      <h2>Packages - <xsl:value-of select="@name"/></h2>
        <table width="100%">
          <xsl:apply-templates select="/radar-report/packages/package[@subsystem=$subsystem-name]" mode="all-packages-link">
            <xsl:sort select="@name"/>
          </xsl:apply-templates>
        </table>
    </body>
  </html>
</xsl:template>

<xsl:template match="package" mode="all-packages-link">
  <tr>
    <td nowrap="nowrap">
         <a href="packages/overview-package-{@name}.html" target="analysisFrame">
        <xsl:value-of select="@name"/>
      </a>
    </td>
  </tr>
</xsl:template>

<xsl:template match="subsystems[position() = last()]" mode="all-subsystems">
  <html>
    <head>
      <link rel="stylesheet" type="text/css" href="stylesheet.css"/>
    </head>
    <body>
  <table width="100%"><tr align="left"><td></td><td align="right">
   </td></tr></table>
      <h2>Subsystems (<xsl:value-of select="@nb-subsystems"/>)</h2>
        <table width="100%">
			<tr>
				<td nowrap="nowrap">
					<a href="#" onClick="parent.frames['packageListFrame'].location='all-packages.html';parent.frames['analysisFrame'].location='subsystems/overview-system.html'">
							All <xsl:value-of select="/radar-report/@system"/>
					</a>
			 	</td>
			</tr>
			<tr>
				<td>
			    	<br/>
			 	</td>
			</tr>
			<xsl:apply-templates select="subsystem" mode="all-subsystems-link">
				<xsl:sort select="@name"/>
			</xsl:apply-templates>
        </table>
    </body>
  </html>
</xsl:template>

	<xsl:template match="subsystem" mode="all-subsystems-link">
		<tr>
			<td nowrap="nowrap">
		      	<a href="#" onClick="parent.frames['packageListFrame'].location='all-packages-subsystem-{@name}.html';parent.frames['analysisFrame'].location='subsystems/overview-subsystem-{@name}.html'">
						<xsl:value-of select="@name"/>
				</a>
		    </td>
	  	</tr>
	</xsl:template>

	<xsl:template name="log-step">
  		<xsl:param name="log"/>
  		<xsl:param name="step"/>
  	    <xsl:choose>
    		<xsl:when test="$log = 'true'">
      			<xsl:message>
>>>>Processing step [<xsl:value-of select="$step"/>]
      			</xsl:message>
      		</xsl:when>
      	</xsl:choose>
  	</xsl:template>

</xsl:stylesheet>
