<?xml version="1.0"  encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
  	extension-element-prefixes="redirect">


<xsl:template name="standard-analysis-test">
	<xsl:param name="reports-element"/>
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>

   	<xsl:variable name="file-identifier">
   		<xsl:choose>
 			<xsl:when test="$single-package='true'">
		 		<xsl:value-of select="$package-element/@name"/>
			</xsl:when>
	        <xsl:otherwise>
	            <xsl:value-of select="$subsystem-name"/>
	        </xsl:otherwise>
        </xsl:choose>
   </xsl:variable>

   <xsl:variable name="catalog-identifier">
   		<xsl:choose>
 			<xsl:when test="$single-package='true'">
		 		<xsl:value-of select="'packages'"/>
			</xsl:when>
	        <xsl:otherwise>
	            <xsl:value-of select="'subsystems'"/>
	        </xsl:otherwise>
        </xsl:choose>
   </xsl:variable>

	<h3>Test Metrics :</h3>
	<p>
	The test count is an indicator of the size of the system. Test coverage is a percentage measuring the fraction of code that has been changed.
	If you divide the test coverage by the test count, you get test coverage per test. This measure should not be increasing for every version,
	since that indicates a larger scope for the test. Test coverage on changed methods measures the amount of tests one has for the code that is maintained.
	</p>
	<table class="details">
	 	<tr><td style="background-color: white;">
		 		<div align="center">
	              <embed width="460" height="275" src="../img/test-count-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
            <td style="background-color: white;"/>
            <td style="background-color: white;">
	            <div align="center">
	              <embed width="460" height="275" src="../img/test-coverage-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
	 	</tr>
	 	<tr><td style="background-color: white;">
		 		<div align="center">
	              <embed width="460" height="275" src="../img/tests-per-method-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
            <td style="background-color: white;"/>
            <td style="background-color: white;">
	            <div align="center">
	              <embed width="460" height="275" src="../img/test-coverage-changed-image-{$file-identifier}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
	            </div>
            </td>
	 	</tr>
	 </table>

	<a href="javascript:winpopanalysisdetails('test-details-popup-{$file-identifier}.html')">[Test Metrics Details]</a><br/>

	<redirect:write file="{$docs-home}/{$catalog-identifier}/test-details-popup-{$file-identifier}.html">
	 <xsl:call-template name="standard-analysis-test-details">
		<xsl:with-param name="reports-element" select="$reports-element"/>
		<xsl:with-param name="packages-element" select="$packages-element"/>
		<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
		<xsl:with-param name="single-package" select="$single-package"/>
		<xsl:with-param name="package-element" select="$package-element"/>
	 </xsl:call-template>
	</redirect:write>

	 <redirect:write file="{$docs-home}/img/test-count-image-{$file-identifier}.svg">
        <xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Test Count'"/>
            <xsl:with-param name="primary-metric-group" select="'test-metrics'"/>
            <xsl:with-param name="primary-metric" select="'tests'"/>

			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
	</redirect:write>

	<redirect:write file="{$docs-home}/img/test-coverage-image-{$file-identifier}.svg">
        <xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Test Coverage [%]'"/>
            <xsl:with-param name="primary-metric-group" select="'test-metrics'"/>
            <xsl:with-param name="primary-metric" select="'source-statements-covered'"/>
            <xsl:with-param name="divisor-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="divisor-metric" select="'ncss'"/>
            <xsl:with-param name="multiplier" select="'100'"/>
			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
	</redirect:write>

    <redirect:write file="{$docs-home}/img/tests-per-method-image-{$file-identifier}.svg">
		 <xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Tests per Method'"/>
            <xsl:with-param name="primary-metric-group" select="'test-metrics'"/>
            <xsl:with-param name="primary-metric" select="'tests'"/>
            <xsl:with-param name="divisor-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="divisor-metric" select="'functions'"/>
			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>
	</redirect:write>


	<redirect:write file="{$docs-home}/img/test-coverage-changed-image-{$file-identifier}.svg">
		<xsl:call-template name="standard-dynamics-line-graph">
            <xsl:with-param name="text-y-axis" select="'Coverage on changed methods [%]'"/>
            <xsl:with-param name="primary-metric-group" select="'test-metrics'"/>
            <xsl:with-param name="primary-metric" select="'source-statements-covered-on-methods-changed'"/>
            <xsl:with-param name="divisor-metric-group" select="'source-metrics'"/>
            <xsl:with-param name="divisor-metric" select="'source-statements-in-methods-changed'"/>
            <xsl:with-param name="multiplier" select="'100'"/>
			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>

<!--        <xsl:call-template name="standard-analysis-test-coverage-changed-graph">
			<xsl:with-param name="reports-element" select="$reports-element"/>
			<xsl:with-param name="packages-element" select="$packages-element"/>
			<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
			<xsl:with-param name="single-package" select="$single-package"/>
			<xsl:with-param name="package-element" select="$package-element"/>
		 </xsl:call-template>-->
	</redirect:write>

</xsl:template>

<xsl:template name="standard-analysis-test-details">
	<xsl:param name="reports-element"/>
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>
	<html>
	<head>
         <link rel="stylesheet" type="text/css" href="../stylesheet.css"/>
	</head>
    <body>

	<table class="details">
		<tr>
			<th>Version</th>
			<th>Date</th>
			<th>Test Suites</th>
			<th>Tests</th>
			<th>Test Coverage [%]</th>
			<th>Test Coverage Per Test [%/10]</th>
			<th>Test Coverage on Changed Methods</th>
		</tr>
		<xsl:for-each select="$reports-element/report">
			<xsl:sort select="@seq-id"/>
			<xsl:variable name="current-seq-id" select="@seq-id"/>

			<xsl:choose>
				<xsl:when test="$single-package='true'">
			 		<xsl:variable name="test-suites" select="sum($package-element/statistics/test-metrics/test-suites/value[@seq-id=$current-seq-id]/@value)"/>
					<xsl:variable name="tests" select="sum($package-element/statistics/test-metrics/tests/value[@seq-id=$current-seq-id]/@value)"/>
					<xsl:variable name="test-coverage" select="100 * sum($package-element/statistics/test-metrics/line-coverage/value[(@seq-id=$current-seq-id) and not(@value='NaN')]/@value)"/>
			 		<tr>
						<td><xsl:value-of select="version"/></td>
						<td><xsl:value-of select="date"/></td>
						<td><xsl:value-of select="$test-suites"/></td>
						<td><xsl:value-of select="$tests"/></td>
						<td><xsl:value-of select="$test-coverage"/></td>
						<td><xsl:value-of select="format-number(10 * $test-coverage div $tests, '#.##')"/></td>
						<td><xsl:value-of select="'todo'"/></td>
					</tr>
				</xsl:when>
		        <xsl:otherwise>
				    <xsl:variable
				    	name="test-suites"
				    	select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/test-metrics/test-suites/value[@seq-id=$current-seq-id]/@value)"/>
					<xsl:variable
						name="tests"
						select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/test-metrics/tests/value[@seq-id=$current-seq-id]/@value)"/>
					<xsl:variable
						name="source-statements-covered"
						select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/test-metrics/source-statements-covered/value[(@seq-id=$current-seq-id) and not(@value='NaN')]/@value)"/>
					<xsl:variable
						name="source-statements"
						select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/ncss/value[(@seq-id=$current-seq-id) and not(@value='NaN')]/@value)"/>
					<xsl:variable
						name="test-coverage"
						select="100 * $source-statements-covered div $source-statements"/>

			 		<tr>
						<td><xsl:value-of select="version"/></td>
						<td><xsl:value-of select="date"/></td>
						<td><xsl:value-of select="$test-suites"/></td>
						<td><xsl:value-of select="$tests"/></td>
						<td><xsl:value-of select="$test-coverage"/></td>
						<td><xsl:value-of select="format-number(10 * $test-coverage div $tests, '#.##')"/></td>
						<td><xsl:value-of select="'todo'"/></td>
					</tr>
		        </xsl:otherwise>
		    </xsl:choose>

		</xsl:for-each>
	</table>

	</body>
	</html>

</xsl:template>



<xsl:template name="standard-analysis-test-coverage-changed-graph">
	<xsl:param name="reports-element"/>
	<xsl:param name="packages-element"/>
	<xsl:param name="subsystem-name"/>
	<xsl:param name="single-package"/>
	<xsl:param name="package-element"/>

	<xsl:call-template name="line-graph">
  		<xsl:with-param name="text-x-axis" select="'Version'"/>
  		<xsl:with-param name="text-y-axis" select="'Coverage on changed methods [%]'"/>
  		<xsl:with-param name="width" select="'1300'"/>
  		<xsl:with-param name="height" select="'800'"/>
  		<xsl:with-param name="point-nodeset">
  			<points>
	  			<xsl:for-each select="$reports-element/report">
	  				<xsl:sort select="@seq-id"/>
	  				<xsl:variable name="current-seq-id" select="@seq-id"/>
	  				<xsl:choose>
						<xsl:when test="$single-package='true'">
			  				<point>
			  					<x-label><xsl:value-of select="version"/></x-label>
			  					<x-coordinate><xsl:value-of select="sum(../report[@seq-id &lt;= $current-seq-id]/days-since-last)"/></x-coordinate>
			  					<y-coordinate><xsl:value-of select="100 * $package-element/statistics/test-metrics/coverage-on-methods-changed/value[@seq-id=$current-seq-id]/@value"/></y-coordinate>
			  				</point>
						</xsl:when>
				        <xsl:otherwise>
			        		<xsl:variable
								name="source-statements-methods-changed"
								select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/source-metrics/source-statements-in-methods-changed/value[(@seq-id=$current-seq-id) and not(@value='NaN') and not(@value='')]/@value)"/>
							<xsl:variable
								name="source-statements-covered-methods-changed"
								select="sum($packages-element/package[starts-with(@subsystem,$subsystem-name)]/statistics/test-metrics/source-statements-covered-on-methods-changed/value[@seq-id=$current-seq-id]/@value)"/>
			  				<point>
			  					<x-label><xsl:value-of select="version"/></x-label>
			  					<x-coordinate><xsl:value-of select="sum(../report[@seq-id &lt;= $current-seq-id]/days-since-last)"/></x-coordinate>
			  					<xsl:choose>
			  						<xsl:when test="$source-statements-methods-changed &gt; 0">
			  							<y-coordinate><xsl:value-of select="100 * ($source-statements-covered-methods-changed div $source-statements-methods-changed)"/></y-coordinate>
			  						</xsl:when>
			  						<xsl:otherwise>
			  							<y-coordinate>0</y-coordinate>
			  						</xsl:otherwise>
			  					</xsl:choose>
			  				</point>
				        </xsl:otherwise>
				    </xsl:choose>
	  			</xsl:for-each>
  			</points>
  		</xsl:with-param>
	</xsl:call-template>

</xsl:template>

</xsl:stylesheet>
