<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
	extension-element-prefixes="redirect">
	<xsl:output method="xml" indent="yes" encoding="UTF-8"/>

	<xsl:include href="xradar://stylesheets/radar/statics/process/master-merge.xsl"/>

	<xsl:param name="input-report-file" />
	<xsl:param name="radar-config-file"/>

	<xsl:variable name="test-depfind-report-doc"
		select="document($input-report-file)"/>
	<xsl:variable name="radar-config-doc"
		select="document($radar-config-file)"/>

    <xsl:variable name="report-source" select="''" />
	<xsl:variable name="report-source-link"
		select="''"/>

	<xsl:template match="/">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="Packages">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:for-each select="Package[count(error)=0]">
				<xsl:variable name="package-name" select="@name"/>
				<xsl:copy>
					<xsl:apply-templates select="@*|node()">
						<xsl:with-param name="depfind-package" select="$test-depfind-report-doc/dependencies/package[name = $package-name]"/>
					</xsl:apply-templates>
				</xsl:copy>
			</xsl:for-each>
			<xsl:for-each select="Package[count(error)&gt;0]">
				<xsl:copy><xsl:apply-templates select="@*|node()"/></xsl:copy>
			</xsl:for-each>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="Stats">
		<xsl:param name="depfind-package"/>
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
			<xsl:apply-templates
				select="$depfind-package" mode="Stats">
			</xsl:apply-templates>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="ConcreteClasses">
		<xsl:param name="depfind-package"/>
		<xsl:copy>
			<xsl:apply-templates select="@*|node()">
				<xsl:with-param name="depfind-package" select="$depfind-package"/>
			</xsl:apply-templates>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="AbstractClasses">
		<xsl:param name="depfind-package"/>
		<xsl:copy>
			<xsl:apply-templates select="@*|node()">
				<xsl:with-param name="depfind-package" select="$depfind-package"/>
			</xsl:apply-templates>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="Class">
		<xsl:param name="depfind-package"/>
		<xsl:variable name="package-name" select="normalize-space(../../@name)"/>
		<xsl:variable name="class-name" select="normalize-space(node())"/>
		<xsl:variable name="depfind-class" select="$depfind-package/class[name=$class-name]"/>

		<xsl:copy>
			<xsl:apply-templates select="@*|node()">
				<xsl:with-param name="depfind-class" select="$depfind-class"/>
				<xsl:with-param name="package-name" select="$package-name"/>
			</xsl:apply-templates>
			<xsl:if test="not(test-metrics)">
				<test-metrics>
					<methods-referenced><xsl:value-of select="count($depfind-class/feature[inbound])"/></methods-referenced>
				</test-metrics>
			</xsl:if>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="test-metrics">
		<xsl:param name="depfind-package"/>
		<xsl:param name="depfind-class"/>
		<xsl:param name="package-name"/>
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
			<xsl:if test="count(../../Class) &gt; 0">
				<methods-referenced><xsl:value-of select="count($depfind-class/feature[inbound])"/></methods-referenced>
			</xsl:if>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="functions">
		<xsl:param name="depfind-class"/>
		<xsl:param name="package-name"/>
		<xsl:copy>
			<xsl:apply-templates select="@*|node()">
				<xsl:with-param name="depfind-class" select="$depfind-class"/>
				<xsl:with-param name="package-name" select="$package-name"/>
			</xsl:apply-templates>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="function">
		<xsl:param name="depfind-class"/>
		<xsl:param name="package-name"/>
		<xsl:variable name="method-name" select="concat(substring-before(normalize-space(name),'('),'(')"/>
		<xsl:variable name="method-params" select="substring-before(substring-after(normalize-space(name),'('),')')"/>
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
			<xsl:for-each select="$depfind-class/feature[starts-with(name,$method-name)]">
				<xsl:call-template name="if-equal-parameters-return-test-coupling-data">
					<xsl:with-param name="orig-param-set" select="$method-params"/>
					<xsl:with-param name="depfind-param-set" select="substring-before(substring-after(name,'('),')')"/>
					<xsl:with-param name="feature" select="current()" />
					<xsl:with-param name="class-name" select="$depfind-class/name" />
					<xsl:with-param name="package-name" select="$package-name" />
				</xsl:call-template>
			</xsl:for-each>
		</xsl:copy>
	</xsl:template>

	<xsl:template name="if-equal-parameters-return-test-coupling-data">
		<xsl:param name="orig-param-set"/>
		<xsl:param name="depfind-param-set"/>
		<xsl:param name="converted-param-set" select="''"/>
		<xsl:param name="feature"/>
		<xsl:param name="class-name"/>
		<xsl:param name="package-name"/>
		<xsl:choose>
			<xsl:when test="contains($depfind-param-set,'.') or contains($depfind-param-set,',')">
				<xsl:choose>
					<xsl:when test="string-length(substring-after($depfind-param-set,'.')) &gt; string-length(substring-after($depfind-param-set,','))">
						<xsl:call-template name="if-equal-parameters-return-test-coupling-data">
							<xsl:with-param name="orig-param-set" select="$orig-param-set"/>
							<xsl:with-param name="depfind-param-set" select="substring-after($depfind-param-set,'.')"/>
							<xsl:with-param name="converted-param-set" select="$converted-param-set"/>
							<xsl:with-param name="feature" select="$feature" />
							<xsl:with-param name="class-name" select="$class-name" />
							<xsl:with-param name="package-name" select="$package-name" />
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="not(contains($depfind-param-set,','))">
						<xsl:call-template name="if-equal-parameters-return-test-coupling-data">
							<xsl:with-param name="orig-param-set" select="$orig-param-set"/>
							<xsl:with-param name="depfind-param-set" select="''"/>
							<xsl:with-param name="converted-param-set" select="concat($converted-param-set,normalize-space($depfind-param-set))"/>
							<xsl:with-param name="feature" select="$feature" />
							<xsl:with-param name="class-name" select="$class-name" />
							<xsl:with-param name="package-name" select="$package-name" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="if-equal-parameters-return-test-coupling-data">
							<xsl:with-param name="orig-param-set" select="$orig-param-set"/>
							<xsl:with-param name="depfind-param-set" select="substring-after($depfind-param-set,',')"/>
							<xsl:with-param name="converted-param-set" select="concat($converted-param-set,normalize-space(substring-before($depfind-param-set,',')),',')"/>
							<xsl:with-param name="feature" select="$feature" />
							<xsl:with-param name="class-name" select="$class-name"/>
							<xsl:with-param name="package-name" select="$package-name" />
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<xsl:when test="not($depfind-param-set = '')">
				<xsl:call-template name="if-equal-parameters-return-test-coupling-data">
					<xsl:with-param name="orig-param-set" select="$orig-param-set"/>
					<xsl:with-param name="depfind-param-set" select="''"/>
					<xsl:with-param name="converted-param-set" select="concat($converted-param-set,normalize-space($depfind-param-set))"/>
					<xsl:with-param name="feature" select="$feature" />
					<xsl:with-param name="class-name" select="$class-name"/>
					<xsl:with-param name="package-name" select="$package-name" />
				</xsl:call-template>
			</xsl:when>

			<xsl:otherwise>
				<xsl:if test="(concat($orig-param-set,',') = $converted-param-set)
									or
							  ($orig-param-set = $converted-param-set)">
					<xsl:apply-templates select="$feature" mode="function">
						<xsl:with-param name="class-name" select="$class-name"/>
						<xsl:with-param name="package-name" select="$package-name" />
					</xsl:apply-templates>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<xsl:template match="feature" mode="function">
		<xsl:param name="class-name"/>
		<xsl:param name="package-name"/>

		<test-coupling>
			<xsl:for-each select="inbound">
				<export type="method"><xsl:value-of select="node()"/></export>
			</xsl:for-each>
		</test-coupling>
	</xsl:template>

	<xsl:template name="package-addition"/>

</xsl:stylesheet>
